==> flutter_i18n-0.12.0.tar.gz: example/lib/namespace_example.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter_i18n/flutter_i18n.dart';
import 'package:flutter_i18n/widgets/I18nText.dart';
import 'package:flutter_localizations/flutter_localizations.dart';

Future main() async {
  final FlutterI18nDelegate flutterI18nDelegate = FlutterI18nDelegate(
    translationLoader: NamespaceFileTranslationLoader(
        namespaces: ["common", "home"],
        useCountryCode: false,
        fallbackDir: 'en',
        basePath: 'assets/i18n_namespace',
        forcedLocale: Locale('it')),
  );
  WidgetsFlutterBinding.ensureInitialized();
  runApp(MyApp(flutterI18nDelegate));
}

class MyApp extends StatelessWidget {
  final FlutterI18nDelegate flutterI18nDelegate;

  MyApp(this.flutterI18nDelegate);

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        primarySwatch: Colors.deepPurple,
      ),
      home: MyHomePage(),
      localizationsDelegates: [
        flutterI18nDelegate,
        GlobalMaterialLocalizations.delegate,
        GlobalWidgetsLocalizations.delegate
      ],
    );
  }
}

class MyHomePage extends StatefulWidget {
  @override
  MyHomeState createState() => MyHomeState();
}

class MyHomeState extends State<MyHomePage> {
  changeLanguage() async {
    final currentLang = FlutterI18n.currentLocale(context);
    final nextLang =
        currentLang.languageCode == 'ua' ? Locale('en') : Locale('ua');
    await FlutterI18n.refresh(context, nextLang);
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar:
          AppBar(title: Text(FlutterI18n.translate(context, "common.title"))),
      body: Builder(builder: (BuildContext context) {
        return Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              I18nText("home.label.main", Text("")),
              RaisedButton(
                  onPressed: () async {
                    await changeLanguage();
                  },
                  child: Text("Change language"))
            ],
          ),
        );
      }),
    );
  }
}

==> flutter_i18n-0.16.1.tar.gz: example/lib/namespace_example.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter_i18n/flutter_i18n.dart';
import 'package:flutter_i18n/widgets/I18nText.dart';
import 'package:flutter_localizations/flutter_localizations.dart';

Future main() async {
  final FlutterI18nDelegate flutterI18nDelegate = FlutterI18nDelegate(
    translationLoader: NamespaceFileTranslationLoader(
        namespaces: ["common", "home"],
        useCountryCode: false,
        fallbackDir: 'en',
        basePath: 'assets/i18n_namespace',
        forcedLocale: Locale('it')),
  );
  WidgetsFlutterBinding.ensureInitialized();
  runApp(MyApp(flutterI18nDelegate));
}

class MyApp extends StatelessWidget {
  final FlutterI18nDelegate flutterI18nDelegate;

  MyApp(this.flutterI18nDelegate);

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        primarySwatch: Colors.deepPurple,
      ),
      home: MyHomePage(),
      localizationsDelegates: [
        flutterI18nDelegate,
        GlobalMaterialLocalizations.delegate,
        GlobalWidgetsLocalizations.delegate
      ],
    );
  }
}

class MyHomePage extends StatefulWidget {
  @override
  MyHomeState createState() => MyHomeState();
}

class MyHomeState extends State<MyHomePage> {
  changeLanguage() async {
    final currentLang = FlutterI18n.currentLocale(context);
    final nextLang =
        currentLang.languageCode == 'ua' ? Locale('en') : Locale('ua');
    await FlutterI18n.refresh(context, nextLang);
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar:
          AppBar(title: Text(FlutterI18n.translate(context, "common.title"))),
      body: Builder(builder: (BuildContext context) {
        return Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              I18nText("home.label.main", child: Text("")),
              RaisedButton(
                  onPressed: () async {
                    await changeLanguage();
                  },
                  child: Text("Change language"))
            ],
          ),
        );
      }),
    );
  }
}
